.. :changelog:

History
-------

0.2.0 (2014-06-23)
++++++++++++++++++

* Added separate search mixins (SingleTermSearchMixin, MultiTermSearchMixin, MapTermSearchMixin).
* Cleanup of docs.


0.1.0 (2014-06-20)
++++++++++++++++++

* First release on PyPI.
